require 'spec_helper'

describe DumpTruck::SchemaConfiguration do
  describe '.new' do
    let(:config) do
      DumpTruck::SchemaConfiguration.new('app_production') do
        target_path '/home/jake/dumps'
        target_name{|schema| schema + Time.at(0).strftime("_%Y%m%d%H%M%S")}

        table(:users){}
      end
    end
    subject{config}

    its(:name){should eq('app_production')}
    its(:target){should eq('/home/jake/dumps/app_production_19691231190000.sql.gz')}
    its(:table_default){should eq(DumpTruck::TableConfiguration.new{truncate})}
    its(:tables){should eq([DumpTruck::TableConfiguration.new(:users)])}
  end

  describe '#table_config_for' do
    context 'with no table configuration' do
      let(:config) do
        DumpTruck::SchemaConfiguration.new('app_production')
      end

      it "uses the default table config" do
        expect(config.table_config_for('cats')).to eq(config.table_default)
      end
    end

    context 'with table config specified' do
      let(:config) do
        DumpTruck::SchemaConfiguration.new('app_production') do
          table(:users){}
        end
      end

      it 'uses the specified table config' do
        expect(config.table_config_for(:users)).to eq(DumpTruck::TableConfiguration.new(:users))
      end
    end
  end
end
