require 'spec_helper'

describe DumpTruck::TableConfiguration do
  describe '.new' do
    context "with no block" do
      let(:config) do
        DumpTruck::TableConfiguration.new('users')
      end
      subject{config}

      its(:name){should eq('users')}
      its(:mode){should eq(:none)}
      its(:query){should be_nil}
    end

    context 'with keep' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep
        end
      end
      subject{config}

      its(:name){should eq('users')}
      its(:mode){should eq(:all)}
      its(:query){should be_nil}
    end

    context 'with keep and query' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep 'deleted_at is null'
        end
      end
      subject{config}

      its(:name){should eq('users')}
      its(:mode){should eq(:some)}
      its(:query){should eq('deleted_at is null')}
    end

    context 'with truncate' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          truncate
        end
      end
      subject{config}

      its(:name){should eq('users')}
      its(:mode){should eq(:none)}
      its(:query){should be_nil}
    end

    context 'with ignore' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          ignore
        end
      end
      subject{config}

      its(:name){should eq('users')}
      its(:mode){should eq(:ignore)}
      its(:query){should be_nil}
    end
  end

  describe '#obfuscate_value' do
    context 'when no obfuscators are specified' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep
        end
      end

      it 'uses the default' do
        expect(config.obfuscate_value('email', 'bob@gmail.com', 1)).to eq('bob@gmail.com')
      end
    end

    context 'when obfuscator is specified with no parameters' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep

          obfuscate(:email){'jim@gmail.com'}
        end
      end

      it 'successfully obfuscates' do
        expect(config.obfuscate_value(:email, 'bob@gmail.com', 1)).to eq('jim@gmail.com')
      end
    end

    context 'when obfuscator is specified with one parameters' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep

          obfuscate(:email){|value| value.reverse}
        end
      end

      it 'successfully obfuscates' do
        expect(config.obfuscate_value(:email, 'bob@gmail.com', 1)).to eq('moc.liamg@bob')
      end
    end

    context 'when obfuscator is specified with two parameters' do
      let(:config) do
        DumpTruck::TableConfiguration.new('users') do
          keep

          obfuscate(:email){|_, n| "test#{n}@gmail.com"}
        end
      end

      it 'successfully obfuscates' do
        expect(config.obfuscate_value(:email, 'bob@gmail.com', 1)).to eq('test1@gmail.com')
      end
    end
  end
end
