require 'spec_helper'

describe DumpTruck::Truck do
  def sql(fixture)
    File.read(File.expand_path("../fixtures/mysql/#{fixture}.sql", __FILE__))
  end

  def sql_io(fixture)
    StringIO.new(sql(fixture))
  end

  let(:sql_dump_file){File.expand_path("../../tmp/app_production.sql.gz", __FILE__)}
  let(:dump_sql){Zlib::GzipReader.open(sql_dump_file){|gz| gz.read}}

  let(:schema_config) do
    DumpTruck::SchemaConfiguration.new('app_production') do
      target_path(File.expand_path('../../tmp', __FILE__))

      table(:users){truncate}
      table(:mail_queue){ignore}
      table(:roles) do
        keep
        obfuscate(:name){|description, n| "#{n}"}
      end
      table(:permissions) do
        keep
        obfuscate(:id){|id| id + 1}
      end
    end
  end

  let(:client) do
    double(DumpTruck::Mysql::Client).tap do |client|
      client.stub(:tables_dump).and_yield(sql_io('tables'))
      client.stub(:data_dump) do |config, &block|
        block.call(sql_io(config.name))
      end
    end
  end

  let(:translator){DumpTruck::Mysql::Translator.new}
  let(:truck){DumpTruck::Truck.new(schema_config, client, translator)}

  after(:each){File.delete(sql_dump_file)}

  it "should successfully dump the output" do
    truck.dump

    expect(dump_sql).to eq(sql('expected_dump'))
  end
end
